(function ($) {
    'use strict';

    /**
     * All of the code for your admin-facing JavaScript source
     * should reside in this file.
     *
     * Note: It has been assumed you will write jQuery code here, so the
     * $ function reference has been prepared for usage within the scope
     * of this function.
     *
     * This enables you to define handlers, for when the DOM is ready:
     *
     * $(function() {
     *
     * });
     *
     * When the window is loaded:
     *
     * $( window ).load(function() {
     *
     * });
     *
     * ...and/or other possibilities.
     *
     * Ideally, it is not considered best practise to attach more than a
     * single DOM-ready or window-load handler for a particular page.
     * Although scripts in the WordPress core, Plugins and Themes may be
     * practising this, we should strive to set a better example in our own work.
     * 
     */
    $(document).ready(function () {
        // only load the scripts we need for the page we're on
        switch ($('#sgc_javascript').val()) {
            case 'sgc_scorecard' :
                let sgc_scorecard = new SGC_Scorecard();
                
                //Hide Post fields
                $('div[id=titlewrap]').hide();			// Title
                $('div[id=postdivrich]').hide();		// Content 
                $('div[id=minor-publishing-actions]').hide();   // Draft and Preview

                //Bind to elements
                $("#publish").click(sgc_scorecard.publish_hook);                    // Publish button
                $("#sgc_scorecard_event").change(sgc_scorecard.event_list_change);   // Event List
                $("#sgc_scorecard_player").change(sgc_scorecard.player_list_change); // Player List
                
                //Load the score content
                $('form').each(sgc_scorecard.load_scorecard);

                break;
            case 'sgc_event' :
                let sgc_event = new SGC_Event( '#sgc_event_group_list', '#sgc_event_group_display', '#sgc_event_group_summary' );

                // Bind to elements
                $('#sgc_event_location').change(sgc_event.location_change);  // Location List
                $('#sgc_event_group_add').click(sgc_event.add_group);        // Group Add button
                $('#sgc_event_group_save').click(sgc_event.save_group_list); // Save group button
                $('#sgc_event_manage_button').click(sgc_event.manage_groups); // Manage Groups button
                
                break;
            case 'sgc_location' :
                let sgc_location = new SGC_Location( '#sgc_location_tees', '#sgc_location_tee_summary');
                
                // Bind to elements
                $('#sgc_location_tee_add').click(sgc_location.add_tee);      // Add Tee button
                $('#sgc_location_tee_delete').click(sgc_location.delete_tee);      // Delete Tee button
                $('#sgc_location_tee_save').click(sgc_location.save_tee);    // Save Tee button
                
                break;
            case 'sgc_player' :
                let sgc_player = new SGC_Player( '#sgc_player_teams',  '#sgc_player_teams_display' );
                
                // bind to elements
                $('#sgc_player_add_team').click(sgc_player.add_team);            // Add Team button
                
                break;
        }
    });

})(jQuery);
