<?php
/**
 * Provide settings and options for SGC configuration
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       https://bitbucket.org/matthewlinton/
 * @since      1.0.0
 *
 * @package    Simplegolfclub
 * @subpackage Simplegolfclub/admin/partials
 */
?>

<h1><?php echo esc_html(get_admin_page_title()); ?></h1>
<form method="post" action="options.php">
    <?php settings_fields($this->plugin_name . '_settings'); ?>
    <?php do_settings_sections($this->plugin_name . '_settings'); ?>
    <table class="form-table">
        <tr>
            <th><label for="sgc_defaultteam"><?= __('Default Team') ?></label></th>
            <td>
                <select name="sgc_defaultteam" id="sgc_defaultteam">
                    <option value=""></option>
                    <?php foreach ($teams as $team) : ?>
                        <option value="<?= $team->ID ?>" 
                            <?php selected($team->ID, esc_attr(get_option('sgc_defaultteam'))); ?>>
                            <?= $team->post_title ?></option>
                    <?php endforeach; ?>
                </select>
            </td>
            <td><?= __('The default team that will automatically be selected when '
                    . 'adding new players and events.') ?></td>
        </tr>
        <tr>
            <th><label for="sgc_defaultlocation"><?= __('Default Location') ?></label></th>
            <td>
                <select name="sgc_defaultlocation" id="sgc_defaultlocation">
                    <option value=""></option>
                    <?php foreach ($locations as $location) : ?>
                        <option value="<?= $location->ID ?>" 
                            <?php selected($location->ID, esc_attr(get_option('sgc_defaultlocation'))); ?>>
                            <?= $location->post_title ?></option>
                    <?php endforeach; ?>
                </select>
            </td>
            <td><?= __('The default location that will automatically be selected '
                    . 'when adding events.') ?></td>
        </tr>
        <tr>
            <th><label for="sgc_defaultunits"><?= __('Units') ?></label></th>
            <td>
                <select name="sgc_defaultunits" id="sgc_defaultunits">
                    <option value="imperial" <?php selected('imperial', 
                        esc_attr(get_option('sgc_defaultunits'))); ?>>
                        <?= __('Imperial (ft/yd)'); ?></option>
                    <option value="metric" <?php selected('metric', 
                        esc_attr(get_option('sgc_defaultunits'))); ?>>
                        <?= __('Metric (cm/m)'); ?></option>
                </select>
            </td>
            <td><?= __('Units to be used for all measurments.') ?></td>
        </tr>
        <tr>
            <th><label for="sgc_default_numevents"><?= __('Number of Dashboard Events') ?>
                </label></th>
            <td>
                <select name="sgc_default_numevents" id="sgc_default_numevents">
                    <option value=""></option>
                    <?php foreach (range(1, 10) as $i) : ?>
                        <option value="<?= $i ?>" <?php selected($i, 
                            esc_attr(get_option('sgc_default_numevents'))); ?>>
                            <?= $i ?></option>
                    <?php endforeach; ?>
                </select>
            </td>
            <td><?= __('Maximum number of events to display for the "Upcoming '
                    . 'Events" and "Past Events" dashboard widgets.') ?> </td>
        </tr>
        <tr>
            <th><label for="sgc_display_personal"><?= __('Display Personal Info.') ?></label></th>
            <td>
                <input type="checkbox" name="sgc_display_personal" value="True"
                       <?php checked(esc_attr(get_option('sgc_display_personal')), 'True'); ?> > <?= __('Yes') ?>
            </td>
            <td><?= __('Should Simple Golf Club display personal information '
                    . '(Emails, Phone Numbers, etc...).') ?> </td>
        </tr>
    </table>

    <?php submit_button(); ?>
</form>
