<?php

/**
 * Class SGC_Public_Players
 * All methods for public facing player posts
 * 
 * @author Matthew Linton
 *
 */

class SGC_Public_Players {
    /**
     *
     */
    public static function get_info( $data = [] ) {
        $name = '';
        $url = '';
        $handicap = '';
        $phone = '';
        $email = '';
        $website = '';
        if( empty( $data ) ) {
            $name = get_the_title(get_the_id());
            $url = get_the_permalink(get_the_id());
            $handicap = get_post_meta(get_the_id(), 'sgc_player_handicap', true);
            if( get_option('sgc_display_personal') == 'True' ) {
                $phone = get_post_meta(get_the_id(), 'sgc_player_phone', true);
                $email = get_post_meta(get_the_id(), 'sgc_player_email', true);
                $website = get_post_meta(get_the_id(), 'sgc_player_website', true);
            }
        } elseif ( ! empty( $data['player_id'] ) ) {
            $name = get_the_title($data['player_id']);
            $url = get_the_permalink($data['player_id']);
            $handicap = get_post_meta($data['player_id'], 'sgc_player_handicap', true);
            if( get_option('sgc_display_personal') == 'True' ) {
                $phone = get_post_meta($data['player_id'], 'sgc_player_phone', true);
                $email = get_post_meta($data['player_id'], 'sgc_player_email', true);
                $website = get_post_meta($data['player_id'], 'sgc_player_website', true);
            }
        } else {
            return [];
        }
        
        return array(
            'name' => $name,
            'URL' => $url,
            'handicap' => $handicap,
            'phone' => $phone,
            'email' => $email,
            'website' => $website
        );
    }
    
    /**
     * 
     */
    public static function get_teams( $data = [] ) {
        $teams = [];
        if( empty( $data ) ) {
            $teams = json_decode( get_post_meta(get_the_id(), 'sgc_player_teams', true), true );
        } elseif ( ! empty( $data['player_id'] ) ) {
            $teams = json_decode( get_post_meta( $data['player_id'], 'sgc_player_teams', true), true);
        } else {
            return [];
        }
        
        // Fetch info for each team in the list
        $teams_list = [];
        foreach( $teams as $team ) {
            array_push( $teams_list, array(
                'name' => $team['name'],
                'URL' => $team['URL']
            ));
        }
        return $teams_list;
    }
    
    /**
     * 
     */
    public static function get_scorecards( $data = [] ) {
        // Set up sane defaults
        $player_id = get_the_id();
        $order = 'DESC';      
        $paged = 1;
        $per_page = 5;
        
        // Get passed values if they exist
        if( ! empty( $data ) ) {
            if( ! empty($data['player_id'] ) ) { $player_id = $data['player_id']; }
            if( ! empty($data['order'] ) ) { $order = $data['order']; }
            if( ! empty($data['paged'] ) ) { $paged = $data['paged']; }
            if( ! empty($data['per_page'] ) ) { $per_page = $data['per_page']; }
        }
        
        //Fetch the scorecards for this player
        $scorecards = get_posts(array(
            'meta_query' => array(
                array(
                    'key' => 'sgc_scorecard_player',
                    'value' => $player_id
                )
            ),
            'post_status' => 'publish',
            'post_type' => 'sgc_scorecard',
            'orderby' => 'post_date',
            'order' => $order,
            'paged' => $paged,
            'posts_per_page' => $per_page
        ));
        
        // Return early if we don't have scorecards
        if ( empty( $scorecards ) ) { return []; }
        
        // Fill the return array with scorecard data
        $player_scores = [];
        foreach( $scorecards as $round ) {
            $event_id = get_post_meta($round->ID, 'sgc_scorecard_event', true);
            $location_id = get_post_meta($event_id, 'sgc_event_location', true);
            $scorecard_tee = get_post_meta( $round->ID, 'sgc_scorecard_tee', true );
            
            // Fetch the tee info 
            $tee_par = [];
            $tee_color = '';
            $tee_diff = '';
            if ( ! empty( $location_id ) ) {
                $tees = get_post_meta( $location_id, 'sgc_location_tees', true);
                if( !empty($tees) ) { 
                    foreach( json_decode( $tees ) as $tee ) {
                        if ( $tee->color == $scorecard_tee ) {
                            $tee_par = $tee->par;
                            $tee_color = $tee->color;
                            $tee_diff = $tee->difficulty;
                            break;
                        }
                    }
                }
            }

            array_push( $player_scores, array(
                'event' => get_the_title( $event_id ),
                'event_url' => get_the_permalink( $event_id ),
                'tee_color' => esc_html($tee_color),
                'tee_difficulty' => esc_html($tee_diff),
                'greens' => esc_html(get_post_meta($round->ID, 'sgc_scorecard_greens', true)),
                'fairways' => esc_html(get_post_meta($round->ID, 'sgc_scorecard_fairways', true)),
                'putts' => esc_html(get_post_meta($round->ID, 'sgc_scorecard_putts', true)),
                'strokes' => json_decode( get_post_meta($round->ID, 'sgc_scorecard_strokes', true) ),
                'par' => $tee_par
            ));
        }
        
        return $player_scores;
    }
    
    /**
     *
     */
    public function add_rest_events() {
        register_rest_route('simplegolfclub/v1', '/player/info/(?P<player_id>\d+)', array(
            'methods' => 'GET',
            'callback' => array('SGC_Public_Players', 'get_info'),
        ));
        register_rest_route('simplegolfclub/v1', '/player/teams/(?P<player_id>\d+)', array(
            'methods' => 'GET',
            'callback' => array('SGC_Public_Players', 'get_teams'),
        ));
        register_rest_route('simplegolfclub/v1', '/player/scorecards/(?P<player_id>\d+)', array(
            'methods' => 'GET',
            'callback' => array('SGC_Public_Players', 'get_scorecards'),
        ));
        
        // Add player team ID meta field when returning player info
        register_meta( 'post', 'sgc_player_team', array(
            'type'         => 'integer',
            'description'  => 'Player Team ID',
            'single'       => true,
            'show_in_rest' => true
         ));
    }
    
    /**
     * 
     */
    public function add_shortcodes () {
        add_shortcode( 'sgc_get_players', array( 'SGC_Public_Players', 'sc_get_players' ) );
    }
    
    /**
     * 
     */
    public static function sc_get_players ( $attr ) {       
        // get attributes
        $sc_attr = shortcode_atts( array(
            'id' => '',
            'name' => '',
            'team_id' => '',
            'team_name' => ''),
            $attr);
        
        // Get Player by ID
        if( !empty($sc_attr['id']) ) {
            return SGC_Public_Players::print_player( $sc_attr['id'] );
            
        // Get Player by Name
        } elseif( !empty($sc_attr['name']) ) {
            $player = get_page_by_title( esc_attr($sc_attr['name']), OBJECT, 'sgc_player' );
            if( $player != null ) { 
                return SGC_Public_Players::print_player( $player->ID );
            } else {
                return '<div class="sgc-sc-warning">'
                    . __('Could not find Player') . ' "' . $sc_attr['name'] . '"'
                    . '</div>';
            }
            
        // Get list of players by team ID
        } elseif( !empty($sc_attr['team_id']) ) {
            return SGC_Public_Players::print_players_by('team', $sc_attr['team_id']);
            
        // Get list of players by team name
        } elseif( !empty($sc_attr['team_name']) ) {
            $team = get_page_by_title( esc_attr($sc_attr['team_name']), OBJECT, 'sgc_team' );
            if( $team != null ) { 
                return SGC_Public_Players::print_players_by( 'team', $team->ID );
            } else {
                return '<div class="sgc-sc-warning">'
                    . __('Could not find Team') . ' "' . $sc_attr['team_name'] . '"'
                    . '</div>';
            }
        }
        return '<div class="sgc-sc-warning">'
            . __('No Players matched your criteria')
            . '</div>';
    }
    
    /**
     * $post_type = [team]
     */
    private static function print_players_by( $post_type, $post_type_id, $sort = 'desc' ) {
        
        // Create the  Meta query
        $meta_q = array( 'realtion' => 'AND' );
        
        // Search by a specific parent post
        if( get_post_type($post_type_id) == 'sgc_' . $post_type ) {
            $meta_q['post_id'] = array(
                'key' => 'sgc_player' . $post_type,
                'value' => $post_type_id);
        } else {
            return '<div class="sgc-sc-warning">' 
                . __('Could not find a parent post for this search')
                . '</div>';
        }
        
        // Fetch players that match
        $players = get_posts(array(
            'post_type' => 'sgc_player',
            'post_status' => 'publish',
            'meta_query' => $meta_q,
            'orderby' => array('post_title' => $sort),
            'posts_per_page' => -1
        ));

        // Build the player list
        $player_list = '';
        foreach( $players as $player ) {
            $player_list .= SGC_Public_Players::print_player($player->ID);
        }
        return $player_list;
    }
    
    /**
     * 
     */
    private static function print_player( $player_id ) {
        if( get_post_type($player_id) == 'sgc_player' 
                && get_post_status($player_id) == 'publish' ) {
            // Fetch scorecard info
            $player_info = SGC_Public_Players::get_info( array( 'player_id' => $player_id ));
            
            // Build the player HREF
            $player_href = '';
            if( !empty($player_info['name']) && !empty($player_info['URL']) ) {
                $player_href = '<a href="' . esc_url($player_info['URL']) . '">' 
                        . esc_html($player_info['name']) . '</a>';
            } elseif( !empty($player_info['name']) ) {
                $player_href = esc_html($player_info['name']);
            }
            
            // Build the player email
            $player_email = '';
            if( !empty($player_info['email']) && get_option('sgc_display_personal') == 'True' ) {
                $player_email = '<a href="mailto:' . esc_html($player_info['email']) . '">' 
                        . esc_html($player_info['email']) . '</a>';
            }
            
            // Buld the player phone link
            $player_phone = '';
            if( !empty($player_info['phone']) && get_option('sgc_display_personal') == 'True' ) {
                $player_phone = '<a href="tel:' . esc_html($player_info['phone']) . '">' 
                        . esc_html($player_info['phone']) . '</a>';
            }
            
            // Build the player website
            $player_web = '';
            if( !empty($player_info['website']) && get_option('sgc_display_personal') == 'True' ) {
                $player_web = '<a href="' . esc_url($player_info['website']) . '">' 
                        . esc_html(parse_url($player_info['website'], PHP_URL_HOST)) . '</a>';
            }
            
            // Build the player info html
            $player_html = '<div class="sgc-sc-player-container">' 
                . '<div class="sgc-sc-player-title">'
                .   $player_href
                . '</div>'
                . '<div class="sgc-sc-player-body">'
                .   '<ul class="sgc-sc-player-info">';
                
            if( !empty($player_email) ) { 
                $player_html .= '<li class="sgc-sc-player-email">' . $player_email . '</li>';
            }
            if( !empty($player_phone) ) {
                $player_html .= '<li class="sgc-sc-player-phone">' . $player_phone . '</li>';
            }
            if( !empty($player_web) ) {
                $player_html .= '<li class="sgc-sc-player-website">' . $player_web . '</li>';
            }
            
            $player_html .= '</ul>'
                . '</div>'
                . '</div>';
            return $player_html;
        }
        return '';
    }
}

// #### BEGIN publicaly accessible PHP function wrappers #######################
if (! function_exists( 'sgc_player_getinfo' )) {
    function sgc_player_getinfo( $data = [] ) {
        return SGC_Public_Players::get_info( $data );
    }
}
if (! function_exists( 'sgc_player_getteams' )) {
    function sgc_player_getteams( $data = [] ) {
        return SGC_Public_Players::get_teams( $data );
    }
}
if (! function_exists( 'sgc_player_getscorecards' )) {
    function sgc_player_getscorecards( $data = [] ) {
        return SGC_Public_Players::get_scorecards( $data );
    }
}
